==> kubernetes-model-apps-5.3.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/apps/ReplicaSetStatusFluent.java <==
package io.fabric8.kubernetes.api.model.apps;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface ReplicaSetStatusFluent<A extends ReplicaSetStatusFluent<A>> extends Fluent<A> {


    public Integer getAvailableReplicas();
    public A withAvailableReplicas(Integer availableReplicas);
    public Boolean hasAvailableReplicas();
    public A withNewAvailableReplicas(int arg1);
    public A addToConditions(int index,ReplicaSetCondition item);
    public A setToConditions(int index,ReplicaSetCondition item);
    public A addToConditions(ReplicaSetCondition... items);
    public A addAllToConditions(Collection<ReplicaSetCondition> items);
    public A removeFromConditions(ReplicaSetCondition... items);
    public A removeAllFromConditions(Collection<ReplicaSetCondition> items);
    public A removeMatchingFromConditions(Predicate<ReplicaSetConditionBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildConditions instead.
 * @return The buildable object.
 */
@Deprecated public List<ReplicaSetCondition> getConditions();
    public List<ReplicaSetCondition> buildConditions();
    public ReplicaSetCondition buildCondition(int index);
    public ReplicaSetCondition buildFirstCondition();
    public ReplicaSetCondition buildLastCondition();
    public ReplicaSetCondition buildMatchingCondition(Predicate<ReplicaSetConditionBuilder> predicate);
    public Boolean hasMatchingCondition(Predicate<ReplicaSetConditionBuilder> predicate);
    public A withConditions(List<ReplicaSetCondition> conditions);
    public A withConditions(ReplicaSetCondition... conditions);
    public Boolean hasConditions();
    public A addNewCondition(String lastTransitionTime,String message,String reason,String status,String type);
    public ReplicaSetStatusFluent.ConditionsNested<A> addNewCondition();
    public ReplicaSetStatusFluent.ConditionsNested<A> addNewConditionLike(ReplicaSetCondition item);
    public ReplicaSetStatusFluent.ConditionsNested<A> setNewConditionLike(int index,ReplicaSetCondition item);
    public ReplicaSetStatusFluent.ConditionsNested<A> editCondition(int index);
    public ReplicaSetStatusFluent.ConditionsNested<A> editFirstCondition();
    public ReplicaSetStatusFluent.ConditionsNested<A> editLastCondition();
    public ReplicaSetStatusFluent.ConditionsNested<A> editMatchingCondition(Predicate<ReplicaSetConditionBuilder> predicate);
    public Integer getFullyLabeledReplicas();
    public A withFullyLabeledReplicas(Integer fullyLabeledReplicas);
    public Boolean hasFullyLabeledReplicas();
    public A withNewFullyLabeledReplicas(int arg1);
    public Long getObservedGeneration();
    public A withObservedGeneration(Long observedGeneration);
    public Boolean hasObservedGeneration();
    public A withNewObservedGeneration(long arg1);
    public Integer getReadyReplicas();
    public A withReadyReplicas(Integer readyReplicas);
    public Boolean hasReadyReplicas();
    public A withNewReadyReplicas(int arg1);
    public Integer getReplicas();
    public A withReplicas(Integer replicas);
    public Boolean hasReplicas();
    public A withNewReplicas(int arg1);
    public interface ConditionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ReplicaSetConditionFluent<ReplicaSetStatusFluent.ConditionsNested<N>> {

            public N and();
            public N endCondition();    }


}

==> kubernetes-model-apps-5.3.2-sources.jar: annotations/io/fabric8/kubernetes/api/model/apps/ReplicaSetStatusFluent.java <==
package io.fabric8.kubernetes.api.model.apps;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface ReplicaSetStatusFluent<A extends ReplicaSetStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    public Integer getAvailableReplicas();
    public A withAvailableReplicas(Integer availableReplicas);
    public Boolean hasAvailableReplicas();
    public A withNewAvailableReplicas(int arg0);
    public A addToConditions(int index,ReplicaSetCondition item);
    public A setToConditions(int index,ReplicaSetCondition item);
    public A addToConditions(ReplicaSetCondition... items);
    public A addAllToConditions(Collection<ReplicaSetCondition> items);
    public A removeFromConditions(ReplicaSetCondition... items);
    public A removeAllFromConditions(Collection<ReplicaSetCondition> items);
    public A removeMatchingFromConditions(Predicate<ReplicaSetConditionBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildConditions instead.
 * @return The buildable object.
 */
@Deprecated public List<ReplicaSetCondition> getConditions();
    public List<ReplicaSetCondition> buildConditions();
    public ReplicaSetCondition buildCondition(int index);
    public ReplicaSetCondition buildFirstCondition();
    public ReplicaSetCondition buildLastCondition();
    public ReplicaSetCondition buildMatchingCondition(Predicate<ReplicaSetConditionBuilder> predicate);
    public Boolean hasMatchingCondition(Predicate<ReplicaSetConditionBuilder> predicate);
    public A withConditions(List<ReplicaSetCondition> conditions);
    public A withConditions(ReplicaSetCondition... conditions);
    public Boolean hasConditions();
    public A addNewCondition(String lastTransitionTime,String message,String reason,String status,String type);
    public io.fabric8.kubernetes.api.model.apps.ReplicaSetStatusFluent.ConditionsNested<A> addNewCondition();
    public io.fabric8.kubernetes.api.model.apps.ReplicaSetStatusFluent.ConditionsNested<A> addNewConditionLike(ReplicaSetCondition item);
    public io.fabric8.kubernetes.api.model.apps.ReplicaSetStatusFluent.ConditionsNested<A> setNewConditionLike(int index,ReplicaSetCondition item);
    public io.fabric8.kubernetes.api.model.apps.ReplicaSetStatusFluent.ConditionsNested<A> editCondition(int index);
    public io.fabric8.kubernetes.api.model.apps.ReplicaSetStatusFluent.ConditionsNested<A> editFirstCondition();
    public io.fabric8.kubernetes.api.model.apps.ReplicaSetStatusFluent.ConditionsNested<A> editLastCondition();
    public io.fabric8.kubernetes.api.model.apps.ReplicaSetStatusFluent.ConditionsNested<A> editMatchingCondition(Predicate<ReplicaSetConditionBuilder> predicate);
    public Integer getFullyLabeledReplicas();
    public A withFullyLabeledReplicas(Integer fullyLabeledReplicas);
    public Boolean hasFullyLabeledReplicas();
    public A withNewFullyLabeledReplicas(int arg0);
    public Long getObservedGeneration();
    public A withObservedGeneration(Long observedGeneration);
    public Boolean hasObservedGeneration();
    public A withNewObservedGeneration(long arg1);
    public Integer getReadyReplicas();
    public A withReadyReplicas(Integer readyReplicas);
    public Boolean hasReadyReplicas();
    public A withNewReadyReplicas(int arg0);
    public Integer getReplicas();
    public A withReplicas(Integer replicas);
    public Boolean hasReplicas();
    public A withNewReplicas(int arg0);
    public interface ConditionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ReplicaSetConditionFluent<io.fabric8.kubernetes.api.model.apps.ReplicaSetStatusFluent.ConditionsNested<N>> {

            public N and();
            public N endCondition();    }


}
